---
title: The Ponds
id: the-ponds
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 9
category: pond
kind: article
---

## The Ponds

Sometimes, having had a surfeit of human society and gossip, and worn
out all my village friends, I rambled still farther westward than I
habitually dwell, into yet more unfrequented parts of the town, “to
fresh woods and pastures new,” or, while the sun was setting, made my
supper of huckleberries and blueberries on Fair Haven Hill, and laid up
a store for several days. The fruits do not yield their true flavor to
the purchaser of them, nor to him who raises them for the market. There
is but one way to obtain it, yet few take that way. If you would know
the flavor of huckleberries, ask the cow-boy or the partridge. It is a
vulgar error to suppose that you have tasted huckleberries who never
plucked them. A huckleberry never reaches Boston; they have not been
known there since they grew on her three hills. The ambrosial and
essential part of the fruit is lost with the bloom which is rubbed off
in the market cart, and they become mere provender. As long as Eternal
Justice reigns, not one innocent huckleberry can be transported thither
from the country’s hills.

Occasionally, after my hoeing was done for the day, I joined some
impatient companion who had been fishing on the pond since morning, as
silent and motionless as a duck or a floating leaf, and, after
practising various kinds of philosophy, had concluded commonly, by the
time I arrived, that he belonged to the ancient sect of Cœnobites.
There was one older man, an excellent fisher and skilled in all kinds
of woodcraft, who was pleased to look upon my house as a building
erected for the convenience of fishermen; and I was equally pleased
when he sat in my doorway to arrange his lines. Once in a while we sat
together on the pond, he at one end of the boat, and I at the other;
but not many words passed between us, for he had grown deaf in his
later years, but he occasionally hummed a psalm, which harmonized well
enough with my philosophy. Our intercourse was thus altogether one of
unbroken harmony, far more pleasing to remember than if it had been
carried on by speech. When, as was commonly the case, I had none to
commune with, I used to raise the echoes by striking with a paddle on
the side of my boat, filling the surrounding woods with circling and
dilating sound, stirring them up as the keeper of a menagerie his wild
beasts, until I elicited a growl from every wooded vale and hill-side.

In warm evenings I frequently sat in the boat playing the flute, and
saw the perch, which I seemed to have charmed, hovering around me, and
the moon travelling over the ribbed bottom, which was strewed with the
wrecks of the forest. Formerly I had come to this pond adventurously,
from time to time, in dark summer nights, with a companion, and making
a fire close to the water’s edge, which we thought attracted the
fishes, we caught pouts with a bunch of worms strung on a thread; and
when we had done, far in the night, threw the burning brands high into
the air like skyrockets, which, coming down into the pond, were
quenched with a loud hissing, and we were suddenly groping in total
darkness. Through this, whistling a tune, we took our way to the haunts
of men again. But now I had made my home by the shore.

Sometimes, after staying in a village parlor till the family had all
retired, I have returned to the woods, and, partly with a view to the
next day’s dinner, spent the hours of midnight fishing from a boat by
moonlight, serenaded by owls and foxes, and hearing, from time to time,
the creaking note of some unknown bird close at hand. These experiences
were very memorable and valuable to me,—anchored in forty feet of
water, and twenty or thirty rods from the shore, surrounded sometimes
by thousands of small perch and shiners, dimpling the surface with
their tails in the moonlight, and communicating by a long flaxen line
with mysterious nocturnal fishes which had their dwelling forty feet
below, or sometimes dragging sixty feet of line about the pond as I
drifted in the gentle night breeze, now and then feeling a slight
vibration along it, indicative of some life prowling about its
extremity, of dull uncertain blundering purpose there, and slow to make
up its mind. At length you slowly raise, pulling hand over hand, some
horned pout squeaking and squirming to the upper air. It was very
queer, especially in dark nights, when your thoughts had wandered to
vast and cosmogonal themes in other spheres, to feel this faint jerk,
which came to interrupt your dreams and link you to Nature again. It
seemed as if I might next cast my line upward into the air, as well as
downward into this element, which was scarcely more dense. Thus I
caught two fishes as it were with one hook.



The scenery of Walden is on a humble scale, and, though very beautiful,
does not approach to grandeur, nor can it much concern one who has not
long frequented it or lived by its shore; yet this pond is so
remarkable for its depth and purity as to merit a particular
description. It is a clear and deep green well, half a mile long and a
mile and three quarters in circumference, and contains about sixty-one
and a half acres; a perennial spring in the midst of pine and oak
woods, without any visible inlet or outlet except by the clouds and
evaporation. The surrounding hills rise abruptly from the water to the
height of forty to eighty feet, though on the south-east and east they
attain to about one hundred and one hundred and fifty feet
respectively, within a quarter and a third of a mile. They are
exclusively woodland. All our Concord waters have two colors at least;
one when viewed at a distance, and another, more proper, close at hand.
The first depends more on the light, and follows the sky. In clear
weather, in summer, they appear blue at a little distance, especially
if agitated, and at a great distance all appear alike. In stormy
weather they are sometimes of a dark slate color. The sea, however, is
said to be blue one day and green another without any perceptible
change in the atmosphere. I have seen our river, when, the landscape
being covered with snow, both water and ice were almost as green as
grass. Some consider blue “to be the color of pure water, whether
liquid or solid.” But, looking directly down into our waters from a
boat, they are seen to be of very different colors. Walden is blue at
one time and green at another, even from the same point of view. Lying
between the earth and the heavens, it partakes of the color of both.
Viewed from a hill-top it reflects the color of the sky; but near at
hand it is of a yellowish tint next the shore where you can see the
sand, then a light green, which gradually deepens to a uniform dark
green in the body of the pond. In some lights, viewed even from a
hill-top, it is of a vivid green next the shore. Some have referred
this to the reflection of the verdure; but it is equally green there
against the railroad sand-bank, and in the spring, before the leaves
are expanded, and it may be simply the result of the prevailing blue
mixed with the yellow of the sand. Such is the color of its iris. This
is that portion, also, where in the spring, the ice being warmed by the
heat of the sun reflected from the bottom, and also transmitted through
the earth, melts first and forms a narrow canal about the still frozen
middle. Like the rest of our waters, when much agitated, in clear
weather, so that the surface of the waves may reflect the sky at the
right angle, or because there is more light mixed with it, it appears
at a little distance of a darker blue than the sky itself; and at such
a time, being on its surface, and looking with divided vision, so as to
see the reflection, I have discerned a matchless and indescribable
light blue, such as watered or changeable silks and sword blades
suggest, more cerulean than the sky itself, alternating with the
original dark green on the opposite sides of the waves, which last
appeared but muddy in comparison. It is a vitreous greenish blue, as I
remember it, like those patches of the winter sky seen through cloud
vistas in the west before sundown. Yet a single glass of its water held
up to the light is as colorless as an equal quantity of air. It is well
known that a large plate of glass will have a green tint, owing, as the
makers say, to its “body,” but a small piece of the same will be
colorless. How large a body of Walden water would be required to
reflect a green tint I have never proved. The water of our river is
black or a very dark brown to one looking directly down on it, and,
like that of most ponds, imparts to the body of one bathing in it a
yellowish tinge; but this water is of such crystalline purity that the
body of the bather appears of an alabaster whiteness, still more
unnatural, which, as the limbs are magnified and distorted withal,
produces a monstrous effect, making fit studies for a Michael Angelo.

The water is so transparent that the bottom can easily be discerned at
the depth of twenty-five or thirty feet. Paddling over it, you may see,
many feet beneath the surface the schools of perch and shiners, perhaps
only an inch long, yet the former easily distinguished by their
transverse bars, and you think that they must be ascetic fish that find
a subsistence there. Once, in the winter, many years ago, when I had
been cutting holes through the ice in order to catch pickerel, as I
stepped ashore I tossed my axe back on to the ice, but, as if some evil
genius had directed it, it slid four or five rods directly into one of
the holes, where the water was twenty-five feet deep. Out of curiosity,
I lay down on the ice and looked through the hole, until I saw the axe
a little on one side, standing on its head, with its helve erect and
gently swaying to and fro with the pulse of the pond; and there it
might have stood erect and swaying till in the course of time the
handle rotted off, if I had not disturbed it. Making another hole
directly over it with an ice chisel which I had, and cutting down the
longest birch which I could find in the neighborhood with my knife, I
made a slip-noose, which I attached to its end, and, letting it down
carefully, passed it over the knob of the handle, and drew it by a line
along the birch, and so pulled the axe out again.

The shore is composed of a belt of smooth rounded white stones like
paving stones, excepting one or two short sand beaches, and is so steep
that in many places a single leap will carry you into water over your
head; and were it not for its remarkable transparency, that would be
the last to be seen of its bottom till it rose on the opposite side.
Some think it is bottomless. It is nowhere muddy, and a casual observer
would say that there were no weeds at all in it; and of noticeable
plants, except in the little meadows recently overflowed, which do not
properly belong to it, a closer scrutiny does not detect a flag nor a
bulrush, nor even a lily, yellow or white, but only a few small
heart-leaves and potamogetons, and perhaps a water-target or two; all
which however a bather might not perceive; and these plants are clean
and bright like the element they grow in. The stones extend a rod or
two into the water, and then the bottom is pure sand, except in the
deepest parts, where there is usually a little sediment, probably from
the decay of the leaves which have been wafted on to it so many
successive falls, and a bright green weed is brought up on anchors even
in midwinter.

We have one other pond just like this, White Pond, in Nine Acre Corner,
about two and a half miles westerly; but, though I am acquainted with
most of the ponds within a dozen miles of this centre I do not know a
third of this pure and well-like character. Successive nations
perchance have drank at, admired, and fathomed it, and passed away, and
still its water is green and pellucid as ever. Not an intermitting
spring! Perhaps on that spring morning when Adam and Eve were driven
out of Eden Walden Pond was already in existence, and even then
breaking up in a gentle spring rain accompanied with mist and a
southerly wind, and covered with myriads of ducks and geese, which had
not heard of the fall, when still such pure lakes sufficed them. Even
then it had commenced to rise and fall, and had clarified its waters
and colored them of the hue they now wear, and obtained a patent of
heaven to be the only Walden Pond in the world and distiller of
celestial dews. Who knows in how many unremembered nations’ literatures
this has been the Castalian Fountain? or what nymphs presided over it
in the Golden Age? It is a gem of the first water which Concord wears
in her coronet.

Yet perchance the first who came to this well have left some trace of
their footsteps. I have been surprised to detect encircling the pond,
even where a thick wood has just been cut down on the shore, a narrow
shelf-like path in the steep hill-side, alternately rising and falling,
approaching and receding from the water’s edge, as old probably as the
race of man here, worn by the feet of aboriginal hunters, and still
from time to time unwittingly trodden by the present occupants of the
land. This is particularly distinct to one standing on the middle of
the pond in winter, just after a light snow has fallen, appearing as a
clear undulating white line, unobscured by weeds and twigs, and very
obvious a quarter of a mile off in many places where in summer it is
hardly distinguishable close at hand. The snow reprints it, as it were,
in clear white type alto-relievo. The ornamented grounds of villas
which will one day be built here may still preserve some trace of this.

The pond rises and falls, but whether regularly or not, and within what
period, nobody knows, though, as usual, many pretend to know. It is
commonly higher in the winter and lower in the summer, though not
corresponding to the general wet and dryness. I can remember when it
was a foot or two lower, and also when it was at least five feet
higher, than when I lived by it. There is a narrow sand-bar running
into it, with very deep water on one side, on which I helped boil a
kettle of chowder, some six rods from the main shore, about the year
1824, which it has not been possible to do for twenty-five years; and
on the other hand, my friends used to listen with incredulity when I
told them, that a few years later I was accustomed to fish from a boat
in a secluded cove in the woods, fifteen rods from the only shore they
knew, which place was long since converted into a meadow. But the pond
has risen steadily for two years, and now, in the summer of ’52, is
just five feet higher than when I lived there, or as high as it was
thirty years ago, and fishing goes on again in the meadow. This makes a
difference of level, at the outside, of six or seven feet; and yet the
water shed by the surrounding hills is insignificant in amount, and
this overflow must be referred to causes which affect the deep springs.
This same summer the pond has begun to fall again. It is remarkable
that this fluctuation, whether periodical or not, appears thus to
require many years for its accomplishment. I have observed one rise and
a part of two falls, and I expect that a dozen or fifteen years hence
the water will again be as low as I have ever known it. Flint’s Pond, a
mile eastward, allowing for the disturbance occasioned by its inlets
and outlets, and the smaller intermediate ponds also, sympathize with
Walden, and recently attained their greatest height at the same time
with the latter. The same is true, as far as my observation goes, of
White Pond.

This rise and fall of Walden at long intervals serves this use at
least; the water standing at this great height for a year or more,
though it makes it difficult to walk round it, kills the shrubs and
trees which have sprung up about its edge since the last rise,
pitch-pines, birches, alders, aspens, and others, and, falling again,
leaves an unobstructed shore; for, unlike many ponds and all waters
which are subject to a daily tide, its shore is cleanest when the water
is lowest. On the side of the pond next my house, a row of pitch pines
fifteen feet high has been killed and tipped over as if by a lever, and
thus a stop put to their encroachments; and their size indicates how
many years have elapsed since the last rise to this height. By this
fluctuation the pond asserts its title to a shore, and thus the _shore_
is _shorn_, and the trees cannot hold it by right of possession. These
are the lips of the lake on which no beard grows. It licks its chaps
from time to time. When the water is at its height, the alders,
willows, and maples send forth a mass of fibrous red roots several feet
long from all sides of their stems in the water, and to the height of
three or four feet from the ground, in the effort to maintain
themselves; and I have known the high-blueberry bushes about the shore,
which commonly produce no fruit, bear an abundant crop under these
circumstances.

Some have been puzzled to tell how the shore became so regularly paved.
My townsmen have all heard the tradition, the oldest people tell me
that they heard it in their youth, that anciently the Indians were
holding a pow-wow upon a hill here, which rose as high into the heavens
as the pond now sinks deep into the earth, and they used much
profanity, as the story goes, though this vice is one of which the
Indians were never guilty, and while they were thus engaged the hill
shook and suddenly sank, and only one old squaw, named Walden, escaped,
and from her the pond was named. It has been conjectured that when the
hill shook these stones rolled down its side and became the present
shore. It is very certain, at any rate, that once there was no pond
here, and now there is one; and this Indian fable does not in any
respect conflict with the account of that ancient settler whom I have
mentioned, who remembers so well when he first came here with his
divining rod, saw a thin vapor rising from the sward, and the hazel
pointed steadily downward, and he concluded to dig a well here. As for
the stones, many still think that they are hardly to be accounted for
by the action of the waves on these hills; but I observe that the
surrounding hills are remarkably full of the same kind of stones, so
that they have been obliged to pile them up in walls on both sides of
the railroad cut nearest the pond; and, moreover, there are most stones
where the shore is most abrupt; so that, unfortunately, it is no longer
a mystery to me. I detect the paver. If the name was not derived from
that of some English locality,—Saffron Walden, for instance,—one might
suppose that it was called originally _Walled-in_ Pond.

The pond was my well ready dug. For four months in the year its water
is as cold as it is pure at all times; and I think that it is then as
good as any, if not the best, in the town. In the winter, all water
which is exposed to the air is colder than springs and wells which are
protected from it. The temperature of the pond water which had stood in
the room where I sat from five o’clock in the afternoon till noon the
next day, the sixth of March, 1846, the thermometer having been up to
65° or 70° some of the time, owing partly to the sun on the roof, was
42°, or one degree colder than the water of one of the coldest wells in
the village just drawn. The temperature of the Boiling Spring the same
day was 45°, or the warmest of any water tried, though it is the
coldest that I know of in summer, when, beside, shallow and stagnant
surface water is not mingled with it. Moreover, in summer, Walden never
becomes so warm as most water which is exposed to the sun, on account
of its depth. In the warmest weather I usually placed a pailful in my
cellar, where it became cool in the night, and remained so during the
day; though I also resorted to a spring in the neighborhood. It was as
good when a week old as the day it was dipped, and had no taste of the
pump. Whoever camps for a week in summer by the shore of a pond, needs
only bury a pail of water a few feet deep in the shade of his camp to
be independent of the luxury of ice.

There have been caught in Walden pickerel, one weighing seven pounds,
to say nothing of another which carried off a reel with great velocity,
which the fisherman safely set down at eight pounds because he did not
see him, perch and pouts, some of each weighing over two pounds,
shiners, chivins or roach (_Leuciscus pulchellus_), a very few breams,
and a couple of eels, one weighing four pounds,—I am thus particular
because the weight of a fish is commonly its only title to fame, and
these are the only eels I have heard of here;—also, I have a faint
recollection of a little fish some five inches long, with silvery sides
and a greenish back, somewhat dace-like in its character, which I
mention here chiefly to link my facts to fable. Nevertheless, this pond
is not very fertile in fish. Its pickerel, though not abundant, are its
chief boast. I have seen at one time lying on the ice pickerel of at
least three different kinds; a long and shallow one, steel-colored,
most like those caught in the river; a bright golden kind, with
greenish reflections and remarkably deep, which is the most common
here; and another, golden-colored, and shaped like the last, but
peppered on the sides with small dark brown or black spots, intermixed
with a few faint blood-red ones, very much like a trout. The specific
name _reticulatus_ would not apply to this; it should be _guttatus_
rather. These are all very firm fish, and weigh more than their size
promises. The shiners, pouts, and perch also, and indeed all the fishes
which inhabit this pond, are much cleaner, handsomer, and firmer
fleshed than those in the river and most other ponds, as the water is
purer, and they can easily be distinguished from them. Probably many
ichthyologists would make new varieties of some of them. There are also
a clean race of frogs and tortoises, and a few muscels in it; muskrats
and minks leave their traces about it, and occasionally a travelling
mud-turtle visits it. Sometimes, when I pushed off my boat in the
morning, I disturbed a great mud-turtle which had secreted himself
under the boat in the night. Ducks and geese frequent it in the spring
and fall, the white-bellied swallows (_Hirundo bicolor_) skim over it,
and the peetweets (_Totanus macularius_) “teter” along its stony shores
all summer. I have sometimes disturbed a fishhawk sitting on a
white-pine over the water; but I doubt if it is ever profaned by the
wing of a gull, like Fair Haven. At most, it tolerates one annual loon.
These are all the animals of consequence which frequent it now.

You may see from a boat, in calm weather, near the sandy eastern shore,
where the water is eight or ten feet deep, and also in some other parts
of the pond, some circular heaps half a dozen feet in diameter by a
foot in height, consisting of small stones less than a hen’s egg in
size, where all around is bare sand. At first you wonder if the Indians
could have formed them on the ice for any purpose, and so, when the ice
melted, they sank to the bottom; but they are too regular and some of
them plainly too fresh for that. They are similar to those found in
rivers; but as there are no suckers nor lampreys here, I know not by
what fish they could be made. Perhaps they are the nests of the chivin.
These lend a pleasing mystery to the bottom.

The shore is irregular enough not to be monotonous. I have in my mind’s
eye the western indented with deep bays, the bolder northern, and the
beautifully scalloped southern shore, where successive capes overlap
each other and suggest unexplored coves between. The forest has never
so good a setting, nor is so distinctly beautiful, as when seen from
the middle of a small lake amid hills which rise from the water’s edge;
for the water in which it is reflected not only makes the best
foreground in such a case, but, with its winding shore, the most
natural and agreeable boundary to it. There is no rawness nor
imperfection in its edge there, as where the axe has cleared a part, or
a cultivated field abuts on it. The trees have ample room to expand on
the water side, and each sends forth its most vigorous branch in that
direction. There Nature has woven a natural selvage, and the eye rises
by just gradations from the low shrubs of the shore to the highest
trees. There are few traces of man’s hand to be seen. The water laves
the shore as it did a thousand years ago.

A lake is the landscape’s most beautiful and expressive feature. It is
earth’s eye; looking into which the beholder measures the depth of his
own nature. The fluviatile trees next the shore are the slender
eyelashes which fringe it, and the wooded hills and cliffs around are
its overhanging brows.

Standing on the smooth sandy beach at the east end of the pond, in a
calm September afternoon, when a slight haze makes the opposite shore
line indistinct, I have seen whence came the expression, “the glassy
surface of a lake.” When you invert your head, it looks like a thread
of finest gossamer stretched across the valley, and gleaming against
the distant pine woods, separating one stratum of the atmosphere from
another. You would think that you could walk dry under it to the
opposite hills, and that the swallows which skim over might perch on
it. Indeed, they sometimes dive below this line, as it were by mistake,
and are undeceived. As you look over the pond westward you are obliged
to employ both your hands to defend your eyes against the reflected as
well as the true sun, for they are equally bright; and if, between the
two, you survey its surface critically, it is literally as smooth as
glass, except where the skater insects, at equal intervals scattered
over its whole extent, by their motions in the sun produce the finest
imaginable sparkle on it, or, perchance, a duck plumes itself, or, as I
have said, a swallow skims so low as to touch it. It may be that in the
distance a fish describes an arc of three or four feet in the air, and
there is one bright flash where it emerges, and another where it
strikes the water; sometimes the whole silvery arc is revealed; or here
and there, perhaps, is a thistle-down floating on its surface, which
the fishes dart at and so dimple it again. It is like molten glass
cooled but not congealed, and the few motes in it are pure and
beautiful like the imperfections in glass. You may often detect a yet
smoother and darker water, separated from the rest as if by an
invisible cobweb, boom of the water nymphs, resting on it. From a
hill-top you can see a fish leap in almost any part; for not a pickerel
or shiner picks an insect from this smooth surface but it manifestly
disturbs the equilibrium of the whole lake. It is wonderful with what
elaborateness this simple fact is advertised,—this piscine murder will
out,—and from my distant perch I distinguish the circling undulations
when they are half a dozen rods in diameter. You can even detect a
water-bug (_Gyrinus_) ceaselessly progressing over the smooth surface a
quarter of a mile off; for they furrow the water slightly, making a
conspicuous ripple bounded by two diverging lines, but the skaters
glide over it without rippling it perceptibly. When the surface is
considerably agitated there are no skaters nor water-bugs on it, but
apparently, in calm days, they leave their havens and adventurously
glide forth from the shore by short impulses till they completely cover
it. It is a soothing employment, on one of those fine days in the fall
when all the warmth of the sun is fully appreciated, to sit on a stump
on such a height as this, overlooking the pond, and study the dimpling
circles which are incessantly inscribed on its otherwise invisible
surface amid the reflected skies and trees. Over this great expanse
there is no disturbance but it is thus at once gently smoothed away and
assuaged, as, when a vase of water is jarred, the trembling circles
seek the shore and all is smooth again. Not a fish can leap or an
insect fall on the pond but it is thus reported in circling dimples, in
lines of beauty, as it were the constant welling up of its fountain,
the gentle pulsing of its life, the heaving of its breast. The thrills
of joy and thrills of pain are undistinguishable. How peaceful the
phenomena of the lake! Again the works of man shine as in the spring.
Ay, every leaf and twig and stone and cobweb sparkles now at
mid-afternoon as when covered with dew in a spring morning. Every
motion of an oar or an insect produces a flash of light; and if an oar
falls, how sweet the echo!

In such a day, in September or October, Walden is a perfect forest
mirror, set round with stones as precious to my eye as if fewer or
rarer. Nothing so fair, so pure, and at the same time so large, as a
lake, perchance, lies on the surface of the earth. Sky water. It needs
no fence. Nations come and go without defiling it. It is a mirror which
no stone can crack, whose quicksilver will never wear off, whose
gilding Nature continually repairs; no storms, no dust, can dim its
surface ever fresh;—a mirror in which all impurity presented to it
sinks, swept and dusted by the sun’s hazy brush,—this the light
dust-cloth,—which retains no breath that is breathed on it, but sends
its own to float as clouds high above its surface, and be reflected in
its bosom still.

A field of water betrays the spirit that is in the air. It is
continually receiving new life and motion from above. It is
intermediate in its nature between land and sky. On land only the grass
and trees wave, but the water itself is rippled by the wind. I see
where the breeze dashes across it by the streaks or flakes of light. It
is remarkable that we can look down on its surface. We shall, perhaps,
look down thus on the surface of air at length, and mark where a still
subtler spirit sweeps over it.

The skaters and water-bugs finally disappear in the latter part of
October, when the severe frosts have come; and then and in November,
usually, in a calm day, there is absolutely nothing to ripple the
surface. One November afternoon, in the calm at the end of a rain storm
of several days’ duration, when the sky was still completely overcast
and the air was full of mist, I observed that the pond was remarkably
smooth, so that it was difficult to distinguish its surface; though it
no longer reflected the bright tints of October, but the sombre
November colors of the surrounding hills. Though I passed over it as
gently as possible, the slight undulations produced by my boat extended
almost as far as I could see, and gave a ribbed appearance to the
reflections. But, as I was looking over the surface, I saw here and
there at a distance a faint glimmer, as if some skater insects which
had escaped the frosts might be collected there, or, perchance, the
surface, being so smooth, betrayed where a spring welled up from the
bottom. Paddling gently to one of these places, I was surprised to find
myself surrounded by myriads of small perch, about five inches long, of
a rich bronze color in the green water, sporting there, and constantly
rising to the surface and dimpling it, sometimes leaving bubbles on it.
In such transparent and seemingly bottomless water, reflecting the
clouds, I seemed to be floating through the air as in a balloon, and
their swimming impressed me as a kind of flight or hovering, as if they
were a compact flock of birds passing just beneath my level on the
right or left, their fins, like sails, set all around them. There were
many such schools in the pond, apparently improving the short season
before winter would draw an icy shutter over their broad skylight,
sometimes giving to the surface an appearance as if a slight breeze
struck it, or a few rain-drops fell there. When I approached carelessly
and alarmed them, they made a sudden splash and rippling with their
tails, as if one had struck the water with a brushy bough, and
instantly took refuge in the depths. At length the wind rose, the mist
increased, and the waves began to run, and the perch leaped much higher
than before, half out of water, a hundred black points, three inches
long, at once above the surface. Even as late as the fifth of December,
one year, I saw some dimples on the surface, and thinking it was going
to rain hard immediately, the air being full of mist, I made haste to
take my place at the oars and row homeward; already the rain seemed
rapidly increasing, though I felt none on my cheek, and I anticipated a
thorough soaking. But suddenly the dimples ceased, for they were
produced by the perch, which the noise of my oars had seared into the
depths, and I saw their schools dimly disappearing; so I spent a dry
afternoon after all.

An old man who used to frequent this pond nearly sixty years ago, when
it was dark with surrounding forests, tells me that in those days he
sometimes saw it all alive with ducks and other water fowl, and that
there were many eagles about it. He came here a-fishing, and used an
old log canoe which he found on the shore. It was made of two
white-pine logs dug out and pinned together, and was cut off square at
the ends. It was very clumsy, but lasted a great many years before it
became water-logged and perhaps sank to the bottom. He did not know
whose it was; it belonged to the pond. He used to make a cable for his
anchor of strips of hickory bark tied together. An old man, a potter,
who lived by the pond before the Revolution, told him once that there
was an iron chest at the bottom, and that he had seen it. Sometimes it
would come floating up to the shore; but when you went toward it, it
would go back into deep water and disappear. I was pleased to hear of
the old log canoe, which took the place of an Indian one of the same
material but more graceful construction, which perchance had first been
a tree on the bank, and then, as it were, fell into the water, to float
there for a generation, the most proper vessel for the lake. I remember
that when I first looked into these depths there were many large trunks
to be seen indistinctly lying on the bottom, which had either been
blown over formerly, or left on the ice at the last cutting, when wood
was cheaper; but now they have mostly disappeared.

When I first paddled a boat on Walden, it was completely surrounded by
thick and lofty pine and oak woods, and in some of its coves grape
vines had run over the trees next the water and formed bowers under
which a boat could pass. The hills which form its shores are so steep,
and the woods on them were then so high, that, as you looked down from
the west end, it had the appearance of an amphitheatre for some kind of
sylvan spectacle. I have spent many an hour, when I was younger,
floating over its surface as the zephyr willed, having paddled my boat
to the middle, and lying on my back across the seats, in a summer
forenoon, dreaming awake, until I was aroused by the boat touching the
sand, and I arose to see what shore my fates had impelled me to; days
when idleness was the most attractive and productive industry. Many a
forenoon have I stolen away, preferring to spend thus the most valued
part of the day; for I was rich, if not in money, in sunny hours and
summer days, and spent them lavishly; nor do I regret that I did not
waste more of them in the workshop or the teacher’s desk. But since I
left those shores the woodchoppers have still further laid them waste,
and now for many a year there will be no more rambling through the
aisles of the wood, with occasional vistas through which you see the
water. My Muse may be excused if she is silent henceforth. How can you
expect the birds to sing when their groves are cut down?

Now the trunks of trees on the bottom, and the old log canoe, and the
dark surrounding woods, are gone, and the villagers, who scarcely know
where it lies, instead of going to the pond to bathe or drink, are
thinking to bring its water, which should be as sacred as the Ganges at
least, to the village in a pipe, to wash their dishes with!—to earn
their Walden by the turning of a cock or drawing of a plug! That
devilish Iron Horse, whose ear-rending neigh is heard throughout the
town, has muddied the Boiling Spring with his foot, and he it is that
has browsed off all the woods on Walden shore, that Trojan horse, with
a thousand men in his belly, introduced by mercenary Greeks! Where is
the country’s champion, the Moore of Moore Hill, to meet him at the
Deep Cut and thrust an avenging lance between the ribs of the bloated
pest?

Nevertheless, of all the characters I have known, perhaps Walden wears
best, and best preserves its purity. Many men have been likened to it,
but few deserve that honor. Though the woodchoppers have laid bare
first this shore and then that, and the Irish have built their sties by
it, and the railroad has infringed on its border, and the ice-men have
skimmed it once, it is itself unchanged, the same water which my
youthful eyes fell on; all the change is in me. It has not acquired one
permanent wrinkle after all its ripples. It is perennially young, and I
may stand and see a swallow dip apparently to pick an insect from its
surface as of yore. It struck me again tonight, as if I had not seen it
almost daily for more than twenty years,—Why, here is Walden, the same
woodland lake that I discovered so many years ago; where a forest was
cut down last winter another is springing up by its shore as lustily as
ever; the same thought is welling up to its surface that was then; it
is the same liquid joy and happiness to itself and its Maker, ay, and
it _may_ be to me. It is the work of a brave man surely, in whom there
was no guile! He rounded this water with his hand, deepened and
clarified it in his thought, and in his will bequeathed it to Concord.
I see by its face that it is visited by the same reflection; and I can
almost say, Walden, is it you?

     It is no dream of mine,
     To ornament a line;
     I cannot come nearer to God and Heaven
     Than I live to Walden even.
     I am its stony shore,
     And the breeze that passes o’er;
     In the hollow of my hand
     Are its water and its sand,
     And its deepest resort
     Lies high in my thought.

The cars never pause to look at it; yet I fancy that the engineers and
firemen and brakemen, and those passengers who have a season ticket and
see it often, are better men for the sight. The engineer does not
forget at night, or his nature does not, that he has beheld this vision
of serenity and purity once at least during the day. Though seen but
once, it helps to wash out State-street and the engine’s soot. One
proposes that it be called “God’s Drop.”

I have said that Walden has no visible inlet nor outlet, but it is on
the one hand distantly and indirectly related to Flint’s Pond, which is
more elevated, by a chain of small ponds coming from that quarter, and
on the other directly and manifestly to Concord River, which is lower,
by a similar chain of ponds through which in some other geological
period it may have flowed, and by a little digging, which God forbid,
it can be made to flow thither again. If by living thus reserved and
austere, like a hermit in the woods, so long, it has acquired such
wonderful purity, who would not regret that the comparatively impure
waters of Flint’s Pond should be mingled with it, or itself should ever
go to waste its sweetness in the ocean wave?



Flint’s, or Sandy Pond, in Lincoln, our greatest lake and inland sea,
lies about a mile east of Walden. It is much larger, being said to
contain one hundred and ninety-seven acres, and is more fertile in
fish; but it is comparatively shallow, and not remarkably pure. A walk
through the woods thither was often my recreation. It was worth the
while, if only to feel the wind blow on your cheek freely, and see the
waves run, and remember the life of mariners. I went a-chestnutting
there in the fall, on windy days, when the nuts were dropping into the
water and were washed to my feet; and one day, as I crept along its
sedgy shore, the fresh spray blowing in my face, I came upon the
mouldering wreck of a boat, the sides gone, and hardly more than the
impression of its flat bottom left amid the rushes; yet its model was
sharply defined, as if it were a large decayed pad, with its veins. It
was as impressive a wreck as one could imagine on the sea-shore, and
had as good a moral. It is by this time mere vegetable mould and
undistinguishable pond shore, through which rushes and flags have
pushed up. I used to admire the ripple marks on the sandy bottom, at
the north end of this pond, made firm and hard to the feet of the wader
by the pressure of the water, and the rushes which grew in Indian file,
in waving lines, corresponding to these marks, rank behind rank, as if
the waves had planted them. There also I have found, in considerable
quantities, curious balls, composed apparently of fine grass or roots,
of pipewort perhaps, from half an inch to four inches in diameter, and
perfectly spherical. These wash back and forth in shallow water on a
sandy bottom, and are sometimes cast on the shore. They are either
solid grass, or have a little sand in the middle. At first you would
say that they were formed by the action of the waves, like a pebble;
yet the smallest are made of equally coarse materials, half an inch
long, and they are produced only at one season of the year. Moreover,
the waves, I suspect, do not so much construct as wear down a material
which has already acquired consistency. They preserve their form when
dry for an indefinite period.

_Flint’s Pond!_ Such is the poverty of our nomenclature. What right had
the unclean and stupid farmer, whose farm abutted on this sky water,
whose shores he has ruthlessly laid bare, to give his name to it? Some
skin-flint, who loved better the reflecting surface of a dollar, or a
bright cent, in which he could see his own brazen face; who regarded
even the wild ducks which settled in it as trespassers; his fingers
grown into crooked and horny talons from the long habit of grasping
harpy-like;—so it is not named for me. I go not there to see him nor to
hear of him; who never _saw_ it, who never bathed in it, who never
loved it, who never protected it, who never spoke a good word for it,
nor thanked God that he had made it. Rather let it be named from the
fishes that swim in it, the wild fowl or quadrupeds which frequent it,
the wild flowers which grow by its shores, or some wild man or child
the thread of whose history is interwoven with its own; not from him
who could show no title to it but the deed which a like-minded neighbor
or legislature gave him,—him who thought only of its money value; whose
presence perchance cursed all the shore; who exhausted the land around
it, and would fain have exhausted the waters within it; who regretted
only that it was not English hay or cranberry meadow,—there was nothing
to redeem it, forsooth, in his eyes,—and would have drained and sold it
for the mud at its bottom. It did not turn his mill, and it was no
_privilege_ to him to behold it. I respect not his labors, his farm
where every thing has its price; who would carry the landscape, who
would carry his God, to market, if he could get any thing for him; who
goes to market _for_ his god as it is; on whose farm nothing grows
free, whose fields bear no crops, whose meadows no flowers, whose trees
no fruits, but dollars; who loves not the beauty of his fruits, whose
fruits are not ripe for him till they are turned to dollars. Give me
the poverty that enjoys true wealth. Farmers are respectable and
interesting to me in proportion as they are poor,—poor farmers. A model
farm! where the house stands like a fungus in a muck-heap, chambers for
men, horses, oxen, and swine, cleansed and uncleansed, all contiguous
to one another! Stocked with men! A great grease-spot, redolent of
manures and buttermilk! Under a high state of cultivation, being
manured with the hearts and brains of men! As if you were to raise your
potatoes in the church-yard! Such is a model farm.

No, no; if the fairest features of the landscape are to be named after
men, let them be the noblest and worthiest men alone. Let our lakes
receive as true names at least as the Icarian Sea, where “still the
shore” a “brave attempt resounds.”



Goose Pond, of small extent, is on my way to Flint’s; Fair-Haven, an
expansion of Concord River, said to contain some seventy acres, is a
mile south-west; and White Pond, of about forty acres, is a mile and a
half beyond Fair-Haven. This is my lake country. These, with Concord
River, are my water privileges; and night and day, year in year out,
they grind such grist as I carry to them.

Since the woodcutters, and the railroad, and I myself have profaned
Walden, perhaps the most attractive, if not the most beautiful, of all
our lakes, the gem of the woods, is White Pond;—a poor name from its
commonness, whether derived from the remarkable purity of its waters or
the color of its sands. In these as in other respects, however, it is a
lesser twin of Walden. They are so much alike that you would say they
must be connected under ground. It has the same stony shore, and its
waters are of the same hue. As at Walden, in sultry dog-day weather,
looking down through the woods on some of its bays which are not so
deep but that the reflection from the bottom tinges them, its waters
are of a misty bluish-green or glaucous color. Many years since I used
to go there to collect the sand by cart-loads, to make sand-paper with,
and I have continued to visit it ever since. One who frequents it
proposes to call it Virid Lake. Perhaps it might be called Yellow-Pine
Lake, from the following circumstance. About fifteen years ago you
could see the top of a pitch-pine, of the kind called yellow-pine
hereabouts, though it is not a distinct species, projecting above the
surface in deep water, many rods from the shore. It was even supposed
by some that the pond had sunk, and this was one of the primitive
forest that formerly stood there. I find that even so long ago as 1792,
in a “Topographical Description of the Town of Concord,” by one of its
citizens, in the Collections of the Massachusetts Historical Society,
the author, after speaking of Walden and White Ponds, adds: “In the
middle of the latter may be seen, when the water is very low, a tree
which appears as if it grew in the place where it now stands, although
the roots are fifty feet below the surface of the water; the top of
this tree is broken off, and at that place measures fourteen inches in
diameter.” In the spring of ’49 I talked with the man who lives nearest
the pond in Sudbury, who told me that it was he who got out this tree
ten or fifteen years before. As near as he could remember, it stood
twelve or fifteen rods from the shore, where the water was thirty or
forty feet deep. It was in the winter, and he had been getting out ice
in the forenoon, and had resolved that in the afternoon, with the aid
of his neighbors, he would take out the old yellow-pine. He sawed a
channel in the ice toward the shore, and hauled it over and along and
out on to the ice with oxen; but, before he had gone far in his work,
he was surprised to find that it was wrong end upward, with the stumps
of the branches pointing down, and the small end firmly fastened in the
sandy bottom. It was about a foot in diameter at the big end, and he
had expected to get a good saw-log, but it was so rotten as to be fit
only for fuel, if for that. He had some of it in his shed then. There
were marks of an axe and of woodpeckers on the butt. He thought that it
might have been a dead tree on the shore, but was finally blown over
into the pond, and after the top had become waterlogged, while the
butt-end was still dry and light, had drifted out and sunk wrong end
up. His father, eighty years old, could not remember when it was not
there. Several pretty large logs may still be seen lying on the bottom,
where, owing to the undulation of the surface, they look like huge
water snakes in motion.

This pond has rarely been profaned by a boat, for there is little in it
to tempt a fisherman. Instead of the white lily, which requires mud, or
the common sweet flag, the blue flag (_Iris versicolor_) grows thinly
in the pure water, rising from the stony bottom all around the shore,
where it is visited by humming birds in June; and the color both of its
bluish blades and its flowers, and especially their reflections, are in
singular harmony with the glaucous water.

White Pond and Walden are great crystals on the surface of the earth,
Lakes of Light. If they were permanently congealed, and small enough to
be clutched, they would, perchance, be carried off by slaves, like
precious stones, to adorn the heads of emperors; but being liquid, and
ample, and secured to us and our successors forever, we disregard them,
and run after the diamond of Kohinoor. They are too pure to have a
market value; they contain no muck. How much more beautiful than our
lives, how much more transparent than our characters, are they! We
never learned meanness of them. How much fairer than the pool before
the farmer’s door, in which his ducks swim! Hither the clean wild ducks
come. Nature has no human inhabitant who appreciates her. The birds
with their plumage and their notes are in harmony with the flowers, but
what youth or maiden conspires with the wild luxuriant beauty of
Nature? She flourishes most alone, far from the towns where they
reside. Talk of heaven! ye disgrace earth.


